==> nextcloud-22.2.10.tgz: nextcloud/apps/workflowengine/l10n/es_AR.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "El operador indicado es inválido",
    "The given regular expression is invalid" : "La expresión regular indicada es inválida",
    "The given file size is invalid" : "El tamaño de archivo indicado es inválido",
    "The given tag id is invalid" : "El id de la etiqueta es inválido",
    "The given IP range is invalid" : "El rango de IP's es inválido",
    "The given IP range is not valid for IPv4" : "El rango de IPs dado no es válido para IPv4",
    "The given IP range is not valid for IPv6" : "El rango de IPs dado no es válido para IPv6",
    "The given time span is invalid" : "El espacio de tiempo dado es inválido",
    "The given start time is invalid" : "El tiempo inicial dado no es válido",
    "The given end time is invalid" : "El tiempo final dado no es válido",
    "The given group does not exist" : "El grupo dado no existe",
    "File" : "Archivo",
    "Operation #%s does not exist" : "La operación #%s  no existe",
    "Operation %s does not exist" : "La operación %s no existe",
    "Operation %s is invalid" : "La operación %s es inválida",
    "Check %s does not exist" : "La validación %s no existe",
    "Check %s is invalid" : "La validación %s no es inválida",
    "Check #%s does not exist" : "La validación #%s no existe",
    "Check %s is invalid or does not exist" : "La validación %s es inválida o no existe",
    "Folder" : "Carpeta",
    "Images" : "Imágenes",
    "No results" : "Sin resultados",
    "%s (invisible)" : "%s (invisible) ",
    "%s (restricted)" : "%s (restringido)",
    "Predefined URLs" : "URLs predefinidos",
    "Files WebDAV" : "Archivos en WebDAV",
    "Android client" : "Cliente Android",
    "iOS client" : "Cliente iOS",
    "Desktop client" : "Cliente de escritorio",
    "Cancel" : "Cancelar",
    "Delete" : "Eliminar",
    "Save" : "Guardar",
    "matches" : "coincide",
    "does not match" : "No coincide",
    "is" : "es",
    "is not" : "no es",
    "File name" : "Nombre",
    "File MIME type" : "Tipo MIME del archivo",
    "File size (upload)" : "Tamaño del archivo (carga)",
    "less" : "menor",
    "less or equals" : "menor o igual",
    "greater or equals" : "mayor o igual",
    "greater" : "mayor",
    "Request remote address" : "Solicitar dirección remota",
    "matches IPv4" : "coincide con IPv4",
    "does not match IPv4" : "no coincide con IPv4",
    "matches IPv6" : "coincide con IPv6",
    "does not match IPv6" : "no coincide con IPv6",
    "File system tag" : "Etiqueta del sistema de archivos",
    "is tagged with" : "está etiquetado con",
    "is not tagged with" : "no está etiquetado con",
    "Request URL" : "Solicitar URL",
    "Request time" : "Tiempo de la solicitud",
    "between" : "entre",
    "not between" : "no entre",
    "Request user agent" : "Solicitar agente de usuario",
    "User group membership" : "Membresia al grupo de usuarios",
    "is member of" : "es miembro de",
    "is not member of" : "no es miembro de"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-24.0.10.tgz: nextcloud/apps/workflowengine/l10n/es_AR.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "El operador indicado es inválido",
    "The given regular expression is invalid" : "La expresión regular indicada es inválida",
    "The given file size is invalid" : "El tamaño de archivo indicado es inválido",
    "The given tag id is invalid" : "El id de la etiqueta es inválido",
    "The given IP range is invalid" : "El rango de IP's es inválido",
    "The given IP range is not valid for IPv4" : "El rango de IPs dado no es válido para IPv4",
    "The given IP range is not valid for IPv6" : "El rango de IPs dado no es válido para IPv6",
    "The given time span is invalid" : "El espacio de tiempo dado es inválido",
    "The given start time is invalid" : "El tiempo inicial dado no es válido",
    "The given end time is invalid" : "El tiempo final dado no es válido",
    "The given group does not exist" : "El grupo dado no existe",
    "File" : "Archivo",
    "Operation #%s does not exist" : "La operación #%s  no existe",
    "Operation %s does not exist" : "La operación %s no existe",
    "Operation %s is invalid" : "La operación %s es inválida",
    "Check %s does not exist" : "La validación %s no existe",
    "Check %s is invalid" : "La validación %s no es inválida",
    "Check #%s does not exist" : "La validación #%s no existe",
    "Check %s is invalid or does not exist" : "La validación %s es inválida o no existe",
    "Folder" : "Carpeta",
    "Images" : "Imágenes",
    "Predefined URLs" : "URLs predefinidos",
    "Files WebDAV" : "Archivos en WebDAV",
    "Android client" : "Cliente Android",
    "iOS client" : "Cliente iOS",
    "Desktop client" : "Cliente de escritorio",
    "Cancel" : "Cancelar",
    "Delete" : "Eliminar",
    "Save" : "Guardar",
    "matches" : "coincide",
    "does not match" : "No coincide",
    "is" : "es",
    "is not" : "no es",
    "File name" : "Nombre",
    "File MIME type" : "Tipo MIME del archivo",
    "File size (upload)" : "Tamaño del archivo (carga)",
    "less" : "menor",
    "less or equals" : "menor o igual",
    "greater or equals" : "mayor o igual",
    "greater" : "mayor",
    "Request remote address" : "Solicitar dirección remota",
    "matches IPv4" : "coincide con IPv4",
    "does not match IPv4" : "no coincide con IPv4",
    "matches IPv6" : "coincide con IPv6",
    "does not match IPv6" : "no coincide con IPv6",
    "File system tag" : "Etiqueta del sistema de archivos",
    "is tagged with" : "está etiquetado con",
    "is not tagged with" : "no está etiquetado con",
    "Request URL" : "Solicitar URL",
    "Request time" : "Tiempo de la solicitud",
    "between" : "entre",
    "not between" : "no entre",
    "Request user agent" : "Solicitar agente de usuario",
    "User group membership" : "Membresia al grupo de usuarios",
    "is member of" : "es miembro de",
    "is not member of" : "no es miembro de",
    "No results" : "Sin resultados",
    "%s (invisible)" : "%s (invisible) ",
    "%s (restricted)" : "%s (restringido)"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
